from django.contrib import admin
from datetime import datetime
from django import forms
from jumbo.admin.options import ExtendibleModelAdmin, OrderedModelAdmin, SettingsAdmin
from faq.models import Question, Topic


class TopicAdmin(ExtendibleModelAdmin):
    prepopulated_fields = {'slug':('name',)}
    fields = ['ordering', 'name', 'slug']
    list_display = ['ordering', 'name', 'slug', 'status', 'get_edit_icon', 'get_delete_icon']

class QuestionAdminSearchForm(forms.ModelForm):
    class Meta:
        model = Question
        display_fields = (
            ('topic__name__icontains', 'text__icontains',),
        )

    def __init__(self, *args, **kws):
        super(QuestionAdminSearchForm, self).__init__(*args, **kws)
        self.fields['topic__name__icontains'] = forms.CharField(label='Topic', required=False)
        self.fields['text__icontains'] = forms.CharField(label='Domanda', required=False)

class QuestionAdmin(ExtendibleModelAdmin):
    list_display = ['text', 'ordering', 'creator', 'date_create', 'status', 'get_edit_icon', 'get_delete_icon']
    default_group_by = 'topic'
    search_form = QuestionAdminSearchForm

    fieldsets = (
        ('logs admin', {'fields': ('creator', 'date_create','last_modifier', 'date_last_modify',), 'classes': ('collapse',)}),
        ("ordinamento", {'fields': ('ordering',), 'classes': ('collapse',),}),
        (None, {"fields": ('slug', 'topic', 'text', 'answer'),}),
    )

admin.site.register(Question, QuestionAdmin)
admin.site.register(Topic, TopicAdmin)