from datetime import datetime

from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User
#from managers import QuestionManager

from jumbo.db.models import DateModel, UserModel, StatusModel, OrderedModel
from jumbo.db import models as jumbo_models


class Topic(StatusModel, OrderedModel):
    """
    Generic Topics for FAQ question grouping
    """
    name = models.CharField(max_length=150)
    slug = models.SlugField(max_length=150)

    class Meta:
        ordering = ['ordering', 'name']

    def __unicode__(self):
        return self.name


class Question(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Represents a frequently asked question.
    """
    slug = models.SlugField( max_length=100, help_text="This is a unique identifier that allows your questions to display its detail view, ex 'how-can-i-contribute'", )
    topic = models.ForeignKey(Topic, related_name="questions")
    text = models.TextField(_('question'), help_text='The actual question itself.')
    answer = models.TextField( _('answer'), help_text='The answer text.' )
    protected = models.BooleanField( default="False", help_text="Set true if this question is only visible by authenticated users." )

    #objects = QuestionManager()

    class Meta:
        ordering = ['ordering', 'date_create', ]

    def __unicode__(self):
        return self.text
