import datetime
from django.views.generic.list_detail import object_detail, object_list
from django.shortcuts import render_to_response
from django.http import HttpResponseRedirect
from django.template import RequestContext
from django.http import Http404
from django.db.models import Q
from models import Question, Topic
#from forms import SubmitFAQForm


def faq_list_topic(request, template_name='faq/faq_list_topic.html', extra_context={}, page=1, paginate_by=10):
    queryset = Topic.objects.filter(status=1)
    return object_list(
        request,
        template_name = template_name,
        extra_context = extra_context,
        queryset = queryset,
        paginate_by = paginate_by,
        page=page,
    )


def faq_topic_question(request, topic_slug, template_name='faq/question_list.html', extra_context={}, page=1, paginate_by=10):
    try:
        topic = Topic.objects.get(slug=topic_slug)
        extra_context.update({'topic':topic})
        questions = topic.questions.filter(status=1)
        extra_context['topic'] = topic
    except:
        raise Http404
    return object_list(
        request,
        template_name = template_name,
        extra_context = extra_context,
        queryset = questions,
        paginate_by = paginate_by,
        page = page,
    )

def faq_search(request, template_name='faq/search_result.html', extra_context={}, page=1, paginate_by=10):
    question_found = Question.objects.none()

    if request.method == 'POST':
        query = request.POST.get('query', None)
        if query:
            extra_context.update({'search_query':query})
            q1 = Q(text__icontains=query)
            q2 = Q(answer__icontains=query)
            question_found = Question.objects.filter(q1|q2)

    return object_list(
        request,
        template_name = template_name,
        extra_context = extra_context,
        queryset = question_found,
        paginate_by = paginate_by,
        page = page,
    )